from setuptools import setup, find_packages

setup(
      name='chroma-bullet',
      version='2.2.0',
      description='Chromas fork of bullet - Beautiful Python prompts made simple.',
      long_description="Extensive support for Python list prompts \
            formatting and colors",
      url='https://github.com/chroma-core/bullet',
      keywords = "cli list prompt customize colors",
      author='THe chroma team and the original bullet author - Mckinsey666',
      license='MIT',
      packages=find_packages(),
      python_requires=">=3.6"
)